==> blancoTmx-0.0.6-src.zip: blancoTmx/blanco/main/blanco/tmx/valueobject/BlancoTmxTu.java <==
/*
 * ̃\[XR[h blanco Frameworkɂ莩܂B
 */
package blanco.tmx.valueobject;

import java.util.List;

/**
 * LISA TMX  tu 킷o[IuWFNgB
 */
public class BlancoTmxTu {
    /**
     * tB[h [tuid]
     *
     * ڂ̌^ [java.lang.String]<br>
     * IDB
     */
    private String fTuid;

    /**
     * tB[h [tuvList]
     *
     * ڂ̌^ [java.util.List<blanco.tmx.valueobject.BlancoTmxTuv>]<br>
     * Kl   [new java.util.ArrayList<blanco.tmx.valueobject.BlancoTmxTuv>()]<br>
     * tuṽXgB
     */
    private List<blanco.tmx.valueobject.BlancoTmxTuv> fTuvList = new java.util.ArrayList<blanco.tmx.valueobject.BlancoTmxTuv>();

    /**
     * tB[h [tuid]̃Zb^[\bh
     *
     * ڂ̌^ [java.lang.String]<br>
     * IDB
     *
     * @param argTuid tB[h[tuid]Ɋi[l
     */
    public void setTuid(final String argTuid) {
        fTuid = argTuid;
    }

    /**
     * tB[h[tuid]̃Qb^[\bh
     *
     * ڂ̌^ [java.lang.String]<br>
     * IDB
     *
     * @return tB[h[tuid]Ɋi[Ăl
     */
    public String getTuid() {
        return fTuid;
    }

    /**
     * tB[h [tuvList]̃Zb^[\bh
     *
     * ڂ̌^ [java.util.List<blanco.tmx.valueobject.BlancoTmxTuv>]<br>
     * tuṽXgB
     *
     * @param argTuvList tB[h[tuvList]Ɋi[l
     */
    public void setTuvList(final List<blanco.tmx.valueobject.BlancoTmxTuv> argTuvList) {
        fTuvList = argTuvList;
    }

    /**
     * tB[h[tuvList]̃Qb^[\bh
     *
     * ڂ̌^ [java.util.List<blanco.tmx.valueobject.BlancoTmxTuv>]<br>
     * Kl   [new java.util.ArrayList<blanco.tmx.valueobject.BlancoTmxTuv>()]<br>
     * tuṽXgB
     *
     * @return tB[h[tuvList]Ɋi[Ăl
     */
    public List<blanco.tmx.valueobject.BlancoTmxTuv> getTuvList() {
        return fTuvList;
    }

    /**
     * ̃o[IuWFNg̕\擾܂B
     *
     * IuWFNg̃V[͈͂łtoStringȂ_ɒӂėpĂB
     *
     * @return o[IuWFNg̕\B
     */
    public String toString() {
        final StringBuffer buf = new StringBuffer();
        buf.append("blanco.tmx.valueobject.BlancoTmxTu[");
        buf.append("tuid=" + fTuid);
        buf.append(",tuvList=" + fTuvList);
        buf.append("]");
        return buf.toString();
    }
}

==> blancoTmx-0.1.1-src.zip: blancoTmx/blanco/main/blanco/tmx/valueobject/BlancoTmxTu.java <==
/*
 * ̃\[XR[h blanco Frameworkɂ莩܂B
 */
package blanco.tmx.valueobject;

import java.util.List;

/**
 * LISA TMX  tu 킷o[IuWFNgB
 */
public class BlancoTmxTu {
    /**
     * tu  IDB
     *
     * tB[h: [tuid]B
     */
    private String fTuid;

    /**
     * tuv ̃XgB
     *
     * tB[h: [tuvList]B
     * ftHg: [new java.util.ArrayList<blanco.tmx.valueobject.BlancoTmxTuv>()]B
     */
    private List<blanco.tmx.valueobject.BlancoTmxTuv> fTuvList = new java.util.ArrayList<blanco.tmx.valueobject.BlancoTmxTuv>();

    /**
     * tB[h [tuid] ̒lݒ肵܂B
     *
     * tB[h̐: [tu  IDB]B
     *
     * @param argTuid tB[h[tuid]ɐݒ肷lB
     */
    public void setTuid(final String argTuid) {
        fTuid = argTuid;
    }

    /**
     * tB[h [tuid] ̒l擾܂B
     *
     * tB[h̐: [tu  IDB]B
     *
     * @return tB[h[tuid]擾lB
     */
    public String getTuid() {
        return fTuid;
    }

    /**
     * tB[h [tuvList] ̒lݒ肵܂B
     *
     * tB[h̐: [tuv ̃XgB]B
     *
     * @param argTuvList tB[h[tuvList]ɐݒ肷lB
     */
    public void setTuvList(final List<blanco.tmx.valueobject.BlancoTmxTuv> argTuvList) {
        fTuvList = argTuvList;
    }

    /**
     * tB[h [tuvList] ̒l擾܂B
     *
     * tB[h̐: [tuv ̃XgB]B
     * ftHg: [new java.util.ArrayList<blanco.tmx.valueobject.BlancoTmxTuv>()]B
     *
     * @return tB[h[tuvList]擾lB
     */
    public List<blanco.tmx.valueobject.BlancoTmxTuv> getTuvList() {
        return fTuvList;
    }

    /**
     * ̃o[IuWFNg̕\擾܂B
     *
     * <P>gp̒</P>
     * <UL>
     * <LI>IuWFNg̃V[͈͂̂ݕ񉻂̏ΏۂƂȂ܂B
     * <LI>IuWFNgzQƂĂꍇɂ́Ã\bh͎gȂłB
     * </UL>
     *
     * @return o[IuWFNg̕\B
     */
    @Override
    public String toString() {
        final StringBuffer buf = new StringBuffer();
        buf.append("blanco.tmx.valueobject.BlancoTmxTu[");
        buf.append("tuid=" + fTuid);
        buf.append(",tuvList=" + fTuvList);
        buf.append("]");
        return buf.toString();
    }
}
